@@ -1,5 +1,7 @@
 """
-Main interface for cloudwatch service client paginators.
+Type annotations for cloudwatch service client paginators.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html)
 
 Usage::
 
@@ -24,18 +26,13 @@ Usage::
     list_metrics_paginator: ListMetricsPaginator = client.get_paginator("list_metrics")
     ```
 """
+import sys
 from datetime import datetime
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_cloudwatch.literals import (
-    AlarmType,
-    HistoryItemType,
-    RecentlyActive,
-    ScanBy,
-    StateValue,
-)
+from mypy_boto3_cloudwatch.literals import AlarmType, HistoryItemType, ScanBy, StateValue
 from mypy_boto3_cloudwatch.type_defs import (
     DescribeAlarmHistoryOutputTypeDef,
     DescribeAlarmsOutputTypeDef,
@@ -48,6 +45,12 @@ from mypy_boto3_cloudwatch.type_defs import (
     PaginatorConfigTypeDef,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 __all__ = (
     "DescribeAlarmHistoryPaginator",
     "DescribeAlarmsPaginator",
@@ -59,7 +62,7 @@ __all__ = (
 
 class DescribeAlarmHistoryPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAlarmHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
     """
 
     def paginate(
@@ -73,13 +76,14 @@ class DescribeAlarmHistoryPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeAlarmHistoryOutputTypeDef]:
         """
-        [DescribeAlarmHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
         """
 
 
 class DescribeAlarmsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAlarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
     """
 
     def paginate(
@@ -94,13 +98,14 @@ class DescribeAlarmsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeAlarmsOutputTypeDef]:
         """
-        [DescribeAlarms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
         """
 
 
 class GetMetricDataPaginator(Boto3Paginator):
     """
-    [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
     """
 
     def paginate(
@@ -113,26 +118,28 @@ class GetMetricDataPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetMetricDataOutputTypeDef]:
         """
-        [GetMetricData.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
         """
 
 
 class ListDashboardsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDashboards documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
     """
 
     def paginate(
         self, DashboardNamePrefix: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDashboardsOutputTypeDef]:
         """
-        [ListDashboards.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
         """
 
 
 class ListMetricsPaginator(Boto3Paginator):
     """
-    [Paginator.ListMetrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
     """
 
     def paginate(
@@ -140,9 +147,10 @@ class ListMetricsPaginator(Boto3Paginator):
         Namespace: str = None,
         MetricName: str = None,
         Dimensions: List[DimensionFilterTypeDef] = None,
-        RecentlyActive: RecentlyActive = None,
+        RecentlyActive: Literal["PT3H"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListMetricsOutputTypeDef]:
         """
-        [ListMetrics.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
         """
